==> spring-cloud-contract-verifier-2.2.5.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/dsl/wiremock/WireMockRequestStubStrategy.java <==
package org.springframework.cloud.contract.verifier.dsl.wiremock;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import static org.springframework.cloud.contract.spec.internal.MatchingStrategy.Type.BINARY_EQUAL_TO;
import static org.springframework.cloud.contract.spec.internal.MatchingType.COMMAND;
import static org.springframework.cloud.contract.spec.internal.MatchingType.EQUALITY;
import static org.springframework.cloud.contract.spec.internal.MatchingType.NULL;
import static org.springframework.cloud.contract.spec.internal.MatchingType.TYPE;
import static org.springframework.cloud.contract.verifier.util.ContentType.FORM;
import static org.springframework.cloud.contract.verifier.util.ContentType.JSON;
import static org.springframework.cloud.contract.verifier.util.ContentUtils.getEqualsTypeFromContentType;
import static org.springframework.cloud.contract.verifier.util.RegexpBuilders.buildGStringRegexpForStubSide;
import static org.springframework.cloud.contract.verifier.util.RegexpBuilders.buildJSONRegexpMatch;
import static org.springframework.cloud.contract.verifier.util.xml.XmlToXPathsConverter.retrieveValue;

@groovy.transform.TypeChecked() @groovy.transform.PackageScope() @groovy.util.logging.Commons() public class WireMockRequestStubStrategy
  extends org.springframework.cloud.contract.verifier.dsl.wiremock.BaseWireMockStubStrategy {
;
public WireMockRequestStubStrategy
(org.springframework.cloud.contract.spec.Contract groovyDsl, org.springframework.cloud.contract.verifier.file.SingleContractMetadata singleContractMetadata) {
super ((org.springframework.cloud.contract.spec.Contract)null);
}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
protected  org.springframework.cloud.contract.verifier.util.ContentType contentType(org.springframework.cloud.contract.verifier.file.SingleContractMetadata singleContractMetadata) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
@groovy.transform.PackageScope() public  com.github.tomakehurst.wiremock.matching.RequestPattern buildClientRequestContent() { return (com.github.tomakehurst.wiremock.matching.RequestPattern)null;}
protected  com.github.tomakehurst.wiremock.matching.ContentPattern convertToValuePattern(java.lang.Object object) { return (com.github.tomakehurst.wiremock.matching.ContentPattern)null;}
protected  java.lang.Object clientBody(java.lang.Object bodyValue, org.springframework.cloud.contract.verifier.util.ContentType contentType) { return null;}
}

==> spring-cloud-contract-verifier-2.2.8.RELEASE-sources.jar: org/springframework/cloud/contract/verifier/dsl/wiremock/WireMockRequestStubStrategy.java <==
package org.springframework.cloud.contract.verifier.dsl.wiremock;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import static org.springframework.cloud.contract.spec.internal.MatchingStrategy.Type.BINARY_EQUAL_TO;
import static org.springframework.cloud.contract.spec.internal.MatchingType.COMMAND;
import static org.springframework.cloud.contract.spec.internal.MatchingType.EQUALITY;
import static org.springframework.cloud.contract.spec.internal.MatchingType.NULL;
import static org.springframework.cloud.contract.spec.internal.MatchingType.TYPE;
import static org.springframework.cloud.contract.verifier.util.ContentType.FORM;
import static org.springframework.cloud.contract.verifier.util.ContentType.JSON;
import static org.springframework.cloud.contract.verifier.util.ContentUtils.getEqualsTypeFromContentType;
import static org.springframework.cloud.contract.verifier.util.RegexpBuilders.buildGStringRegexpForStubSide;
import static org.springframework.cloud.contract.verifier.util.RegexpBuilders.buildJSONRegexpMatch;
import static org.springframework.cloud.contract.verifier.util.xml.XmlToXPathsConverter.retrieveValue;

@groovy.transform.TypeChecked() @groovy.transform.PackageScope() @groovy.util.logging.Commons() public class WireMockRequestStubStrategy
  extends org.springframework.cloud.contract.verifier.dsl.wiremock.BaseWireMockStubStrategy  implements
    groovy.lang.GroovyObject {
;
public WireMockRequestStubStrategy
(org.springframework.cloud.contract.spec.Contract groovyDsl, org.springframework.cloud.contract.verifier.file.SingleContractMetadata singleContractMetadata) {
super ((org.springframework.cloud.contract.spec.Contract)null);
}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
protected  org.springframework.cloud.contract.verifier.util.ContentType contentType(org.springframework.cloud.contract.verifier.file.SingleContractMetadata singleContractMetadata) { return (org.springframework.cloud.contract.verifier.util.ContentType)null;}
@groovy.transform.PackageScope() public  com.github.tomakehurst.wiremock.matching.RequestPattern buildClientRequestContent() { return (com.github.tomakehurst.wiremock.matching.RequestPattern)null;}
protected  com.github.tomakehurst.wiremock.matching.ContentPattern convertToValuePattern(java.lang.Object object) { return (com.github.tomakehurst.wiremock.matching.ContentPattern)null;}
protected  java.lang.Object clientBody(java.lang.Object bodyValue, org.springframework.cloud.contract.verifier.util.ContentType contentType) { return null;}
}
